@@ -5,12 +5,14 @@ import os
 import tomlkit
 from packaging.markers import default_environment
 
+from pdm.formats.base import make_array
 from pdm.models.markers import Marker
+from pdm.models.requirements import Requirement
 
 MARKER_KEYS = list(default_environment().keys())
 
 
-def convert_pipfile_requirement(req):
+def convert_pipfile_requirement(name, req):
     markers = []
 
     if "markers" in req:
@@ -24,7 +26,7 @@ def convert_pipfile_requirement(req):
     if markers:
         marker = functools.reduce(operator.and_, markers)
         req["marker"] = str(marker).replace('"', "'")
-    return req
+    return Requirement.from_req_dict(name, req).as_line()
 
 
 def check_fingerprint(project, filename):
@@ -35,24 +37,31 @@ def convert(project, filename):
     with open(filename, encoding="utf-8") as fp:
         data = tomlkit.parse(fp.read())
     result = {}
+    settings = {}
     if "pipenv" in data:
-        result["allow_prereleases"] = data["pipenv"].get("allow_prereleases", False)
+        settings["allow_prereleases"] = data["pipenv"].get("allow_prereleases", False)
     if "requires" in data:
         python_version = data["requires"].get("python_full_version") or data[
             "requires"
         ].get("python_version")
-        result["python_requires"] = f">={python_version}"
+        result["requires-python"] = f">={python_version}"
     if "source" in data:
-        result["source"] = data["source"]
-    result["dependencies"] = {
-        k: convert_pipfile_requirement(req)
-        for k, req in data.get("packages", {}).items()
-    }
-    result["dev-dependencies"] = {
-        k: convert_pipfile_requirement(req)
-        for k, req in data.get("dev-packages", {}).items()
-    }
-    return result
+        settings["source"] = data["source"]
+    result["dependencies"] = make_array(
+        [
+            convert_pipfile_requirement(k, req)
+            for k, req in data.get("packages", {}).items()
+        ],
+        True,
+    )
+    result["dev-dependencies"] = make_array(
+        [
+            convert_pipfile_requirement(k, req)
+            for k, req in data.get("dev-packages", {}).items()
+        ],
+        True,
+    )
+    return result, settings
 
 
 def export(project, candidates, options):
